__all__ = ['VITAE']

from VITAE.VITAE import VITAE, get_embedding, get_igraph, leidenalg_igraph, plot_clusters, load_data

__author__ = "Jin-Hong Du, Ming Gao, and Jingshu Wang"
__copyright__ = "Copyright 2020, The Trajectory Inference Project"

__license__ = "MIT"
__version__ = "1.1.5"
__maintainer__ = "Jin-Hong Du"
__email__ = "dujinhong@uchicago.edu"
__status__ = "Development"